# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectFormat(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'latest_version': 'bool',
        'partition_key': 'str',
        'description': 'str',
        'document_schema': 'str',
        'document_schema_url': 'str',
        'attributes': 'list[Attribute]',
        'attribute_definitions': 'list[AttributeDefinition]',
        'enable_business_object_data_published_attributes_change_event_notification': 'bool',
        'schema': 'Schema',
        'business_object_format_parents': 'list[BusinessObjectFormatKey]',
        'business_object_format_children': 'list[BusinessObjectFormatKey]',
        'business_object_format_external_interfaces': 'list[BusinessObjectFormatExternalInterfaceKey]',
        'record_flag': 'bool',
        'legal_hold': 'bool',
        'retention_period_in_days': 'int',
        'retention_type': 'str',
        'allow_non_backwards_compatible_changes': 'bool',
        'relational_schema_name': 'str',
        'relational_table_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'latest_version': 'latestVersion',
        'partition_key': 'partitionKey',
        'description': 'description',
        'document_schema': 'documentSchema',
        'document_schema_url': 'documentSchemaUrl',
        'attributes': 'attributes',
        'attribute_definitions': 'attributeDefinitions',
        'enable_business_object_data_published_attributes_change_event_notification': 'enableBusinessObjectDataPublishedAttributesChangeEventNotification',
        'schema': 'schema',
        'business_object_format_parents': 'businessObjectFormatParents',
        'business_object_format_children': 'businessObjectFormatChildren',
        'business_object_format_external_interfaces': 'businessObjectFormatExternalInterfaces',
        'record_flag': 'recordFlag',
        'legal_hold': 'legalHold',
        'retention_period_in_days': 'retentionPeriodInDays',
        'retention_type': 'retentionType',
        'allow_non_backwards_compatible_changes': 'allowNonBackwardsCompatibleChanges',
        'relational_schema_name': 'relationalSchemaName',
        'relational_table_name': 'relationalTableName'
    }

    def __init__(self, id=None, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, latest_version=None, partition_key=None, description=None, document_schema=None, document_schema_url=None, attributes=None, attribute_definitions=None, enable_business_object_data_published_attributes_change_event_notification=None, schema=None, business_object_format_parents=None, business_object_format_children=None, business_object_format_external_interfaces=None, record_flag=None, legal_hold=None, retention_period_in_days=None, retention_type=None, allow_non_backwards_compatible_changes=None, relational_schema_name=None, relational_table_name=None):  # noqa: E501
        """BusinessObjectFormat - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._latest_version = None
        self._partition_key = None
        self._description = None
        self._document_schema = None
        self._document_schema_url = None
        self._attributes = None
        self._attribute_definitions = None
        self._enable_business_object_data_published_attributes_change_event_notification = None
        self._schema = None
        self._business_object_format_parents = None
        self._business_object_format_children = None
        self._business_object_format_external_interfaces = None
        self._record_flag = None
        self._legal_hold = None
        self._retention_period_in_days = None
        self._retention_type = None
        self._allow_non_backwards_compatible_changes = None
        self._relational_schema_name = None
        self._relational_table_name = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        if latest_version is not None:
            self.latest_version = latest_version
        self.partition_key = partition_key
        if description is not None:
            self.description = description
        if document_schema is not None:
            self.document_schema = document_schema
        if document_schema_url is not None:
            self.document_schema_url = document_schema_url
        if attributes is not None:
            self.attributes = attributes
        if attribute_definitions is not None:
            self.attribute_definitions = attribute_definitions
        if enable_business_object_data_published_attributes_change_event_notification is not None:
            self.enable_business_object_data_published_attributes_change_event_notification = enable_business_object_data_published_attributes_change_event_notification
        if schema is not None:
            self.schema = schema
        if business_object_format_parents is not None:
            self.business_object_format_parents = business_object_format_parents
        if business_object_format_children is not None:
            self.business_object_format_children = business_object_format_children
        if business_object_format_external_interfaces is not None:
            self.business_object_format_external_interfaces = business_object_format_external_interfaces
        if record_flag is not None:
            self.record_flag = record_flag
        if legal_hold is not None:
            self.legal_hold = legal_hold
        if retention_period_in_days is not None:
            self.retention_period_in_days = retention_period_in_days
        if retention_type is not None:
            self.retention_type = retention_type
        if allow_non_backwards_compatible_changes is not None:
            self.allow_non_backwards_compatible_changes = allow_non_backwards_compatible_changes
        if relational_schema_name is not None:
            self.relational_schema_name = relational_schema_name
        if relational_table_name is not None:
            self.relational_table_name = relational_table_name

    @property
    def id(self):
        """Gets the id of this BusinessObjectFormat.  # noqa: E501

        The internal identifier that uniquely identifies a Business Object Format  # noqa: E501

        :return: The id of this BusinessObjectFormat.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BusinessObjectFormat.

        The internal identifier that uniquely identifies a Business Object Format  # noqa: E501

        :param id: The id of this BusinessObjectFormat.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectFormat.  # noqa: E501

        The Namespace to which a Business Object Format is related  # noqa: E501

        :return: The namespace of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectFormat.

        The Namespace to which a Business Object Format is related  # noqa: E501

        :param namespace: The namespace of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectFormat.  # noqa: E501

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectFormat.

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectFormat.  # noqa: E501

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :return: The business_object_format_usage of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectFormat.

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectFormat.  # noqa: E501

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :return: The business_object_format_file_type of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectFormat.

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectFormat.  # noqa: E501

        The numeric version of a Business Object Format. Each time a format is registered, the new version will be the previous version                   + 1                  # noqa: E501

        :return: The business_object_format_version of this BusinessObjectFormat.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectFormat.

        The numeric version of a Business Object Format. Each time a format is registered, the new version will be the previous version                   + 1                  # noqa: E501

        :param business_object_format_version: The business_object_format_version of this BusinessObjectFormat.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def latest_version(self):
        """Gets the latest_version of this BusinessObjectFormat.  # noqa: E501

        A Y/N flag that shows whether this instance of format is the latest or not. Once a new version of format is registered, any                   previous versions will no longer be the latest                  # noqa: E501

        :return: The latest_version of this BusinessObjectFormat.  # noqa: E501
        :rtype: bool
        """
        return self._latest_version

    @latest_version.setter
    def latest_version(self, latest_version):
        """Sets the latest_version of this BusinessObjectFormat.

        A Y/N flag that shows whether this instance of format is the latest or not. Once a new version of format is registered, any                   previous versions will no longer be the latest                  # noqa: E501

        :param latest_version: The latest_version of this BusinessObjectFormat.  # noqa: E501
        :type: bool
        """

        self._latest_version = latest_version

    @property
    def partition_key(self):
        """Gets the partition_key of this BusinessObjectFormat.  # noqa: E501

        The partition key for this Business Object Format  # noqa: E501

        :return: The partition_key of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._partition_key

    @partition_key.setter
    def partition_key(self, partition_key):
        """Sets the partition_key of this BusinessObjectFormat.

        The partition key for this Business Object Format  # noqa: E501

        :param partition_key: The partition_key of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """
        if partition_key is None:
            raise ValueError("Invalid value for `partition_key`, must not be `None`")  # noqa: E501

        self._partition_key = partition_key

    @property
    def description(self):
        """Gets the description of this BusinessObjectFormat.  # noqa: E501

        Description of the Business Object Format  # noqa: E501

        :return: The description of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BusinessObjectFormat.

        Description of the Business Object Format  # noqa: E501

        :param description: The description of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def document_schema(self):
        """Gets the document_schema of this BusinessObjectFormat.  # noqa: E501

        The schema for document-style business object data registered with Herd  # noqa: E501

        :return: The document_schema of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._document_schema

    @document_schema.setter
    def document_schema(self, document_schema):
        """Sets the document_schema of this BusinessObjectFormat.

        The schema for document-style business object data registered with Herd  # noqa: E501

        :param document_schema: The document_schema of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """

        self._document_schema = document_schema

    @property
    def document_schema_url(self):
        """Gets the document_schema_url of this BusinessObjectFormat.  # noqa: E501

        An optional URL of the documentSchema to an externally hosted XSD or JSON. Herd will not access this URL,                   it will simply store and retrieve the URL and teams can then access the URL                  # noqa: E501

        :return: The document_schema_url of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._document_schema_url

    @document_schema_url.setter
    def document_schema_url(self, document_schema_url):
        """Sets the document_schema_url of this BusinessObjectFormat.

        An optional URL of the documentSchema to an externally hosted XSD or JSON. Herd will not access this URL,                   it will simply store and retrieve the URL and teams can then access the URL                  # noqa: E501

        :param document_schema_url: The document_schema_url of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """

        self._document_schema_url = document_schema_url

    @property
    def attributes(self):
        """Gets the attributes of this BusinessObjectFormat.  # noqa: E501

        Custom user-defined metadata associated with this Business Object Format. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value.                  # noqa: E501

        :return: The attributes of this BusinessObjectFormat.  # noqa: E501
        :rtype: list[Attribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this BusinessObjectFormat.

        Custom user-defined metadata associated with this Business Object Format. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value.                  # noqa: E501

        :param attributes: The attributes of this BusinessObjectFormat.  # noqa: E501
        :type: list[Attribute]
        """

        self._attributes = attributes

    @property
    def attribute_definitions(self):
        """Gets the attribute_definitions of this BusinessObjectFormat.  # noqa: E501

        List of attribute definitions (for storage of custom user-defined metadata with objects) which are required to be specified                   when registering Business Object Data against this format. This list will define which metadata must be specified, but additional metadata can                   still be registered which is not specified in this list. The metadata (attributes) will allow applications to store custom data with                   registered data for use by consumers of the data                  # noqa: E501

        :return: The attribute_definitions of this BusinessObjectFormat.  # noqa: E501
        :rtype: list[AttributeDefinition]
        """
        return self._attribute_definitions

    @attribute_definitions.setter
    def attribute_definitions(self, attribute_definitions):
        """Sets the attribute_definitions of this BusinessObjectFormat.

        List of attribute definitions (for storage of custom user-defined metadata with objects) which are required to be specified                   when registering Business Object Data against this format. This list will define which metadata must be specified, but additional metadata can                   still be registered which is not specified in this list. The metadata (attributes) will allow applications to store custom data with                   registered data for use by consumers of the data                  # noqa: E501

        :param attribute_definitions: The attribute_definitions of this BusinessObjectFormat.  # noqa: E501
        :type: list[AttributeDefinition]
        """

        self._attribute_definitions = attribute_definitions

    @property
    def enable_business_object_data_published_attributes_change_event_notification(self):
        """Gets the enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormat.  # noqa: E501

        If true, enables Business Object Data Published Attributes Change Event Notification for all business object data registered                   under this business object format version                  # noqa: E501

        :return: The enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormat.  # noqa: E501
        :rtype: bool
        """
        return self._enable_business_object_data_published_attributes_change_event_notification

    @enable_business_object_data_published_attributes_change_event_notification.setter
    def enable_business_object_data_published_attributes_change_event_notification(self, enable_business_object_data_published_attributes_change_event_notification):
        """Sets the enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormat.

        If true, enables Business Object Data Published Attributes Change Event Notification for all business object data registered                   under this business object format version                  # noqa: E501

        :param enable_business_object_data_published_attributes_change_event_notification: The enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormat.  # noqa: E501
        :type: bool
        """

        self._enable_business_object_data_published_attributes_change_event_notification = enable_business_object_data_published_attributes_change_event_notification

    @property
    def schema(self):
        """Gets the schema of this BusinessObjectFormat.  # noqa: E501


        :return: The schema of this BusinessObjectFormat.  # noqa: E501
        :rtype: Schema
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this BusinessObjectFormat.


        :param schema: The schema of this BusinessObjectFormat.  # noqa: E501
        :type: Schema
        """

        self._schema = schema

    @property
    def business_object_format_parents(self):
        """Gets the business_object_format_parents of this BusinessObjectFormat.  # noqa: E501

        A list of Business Object Data parents (i.e. predecessors) that were used/needed in the creation of this data. This is used for                   data lineage. Each parent consists of the key data that uniquely defines a reference to a single Business Object Data.                  # noqa: E501

        :return: The business_object_format_parents of this BusinessObjectFormat.  # noqa: E501
        :rtype: list[BusinessObjectFormatKey]
        """
        return self._business_object_format_parents

    @business_object_format_parents.setter
    def business_object_format_parents(self, business_object_format_parents):
        """Sets the business_object_format_parents of this BusinessObjectFormat.

        A list of Business Object Data parents (i.e. predecessors) that were used/needed in the creation of this data. This is used for                   data lineage. Each parent consists of the key data that uniquely defines a reference to a single Business Object Data.                  # noqa: E501

        :param business_object_format_parents: The business_object_format_parents of this BusinessObjectFormat.  # noqa: E501
        :type: list[BusinessObjectFormatKey]
        """

        self._business_object_format_parents = business_object_format_parents

    @property
    def business_object_format_children(self):
        """Gets the business_object_format_children of this BusinessObjectFormat.  # noqa: E501

        A list of Business Object Data children that were creation from this data. This is used for data lineage. Each child consists                   of the key data that uniquely defines a reference to a single Business Object Data.                  # noqa: E501

        :return: The business_object_format_children of this BusinessObjectFormat.  # noqa: E501
        :rtype: list[BusinessObjectFormatKey]
        """
        return self._business_object_format_children

    @business_object_format_children.setter
    def business_object_format_children(self, business_object_format_children):
        """Sets the business_object_format_children of this BusinessObjectFormat.

        A list of Business Object Data children that were creation from this data. This is used for data lineage. Each child consists                   of the key data that uniquely defines a reference to a single Business Object Data.                  # noqa: E501

        :param business_object_format_children: The business_object_format_children of this BusinessObjectFormat.  # noqa: E501
        :type: list[BusinessObjectFormatKey]
        """

        self._business_object_format_children = business_object_format_children

    @property
    def business_object_format_external_interfaces(self):
        """Gets the business_object_format_external_interfaces of this BusinessObjectFormat.  # noqa: E501

        A list of business object format to external interface mappings  # noqa: E501

        :return: The business_object_format_external_interfaces of this BusinessObjectFormat.  # noqa: E501
        :rtype: list[BusinessObjectFormatExternalInterfaceKey]
        """
        return self._business_object_format_external_interfaces

    @business_object_format_external_interfaces.setter
    def business_object_format_external_interfaces(self, business_object_format_external_interfaces):
        """Sets the business_object_format_external_interfaces of this BusinessObjectFormat.

        A list of business object format to external interface mappings  # noqa: E501

        :param business_object_format_external_interfaces: The business_object_format_external_interfaces of this BusinessObjectFormat.  # noqa: E501
        :type: list[BusinessObjectFormatExternalInterfaceKey]
        """

        self._business_object_format_external_interfaces = business_object_format_external_interfaces

    @property
    def record_flag(self):
        """Gets the record_flag of this BusinessObjectFormat.  # noqa: E501

        Indicates if business object data registered with this format is a record                  # noqa: E501

        :return: The record_flag of this BusinessObjectFormat.  # noqa: E501
        :rtype: bool
        """
        return self._record_flag

    @record_flag.setter
    def record_flag(self, record_flag):
        """Sets the record_flag of this BusinessObjectFormat.

        Indicates if business object data registered with this format is a record                  # noqa: E501

        :param record_flag: The record_flag of this BusinessObjectFormat.  # noqa: E501
        :type: bool
        """

        self._record_flag = record_flag

    @property
    def legal_hold(self):
        """Gets the legal_hold of this BusinessObjectFormat.  # noqa: E501

        Indicate if this Business Object Format is under legal hold  # noqa: E501

        :return: The legal_hold of this BusinessObjectFormat.  # noqa: E501
        :rtype: bool
        """
        return self._legal_hold

    @legal_hold.setter
    def legal_hold(self, legal_hold):
        """Sets the legal_hold of this BusinessObjectFormat.

        Indicate if this Business Object Format is under legal hold  # noqa: E501

        :param legal_hold: The legal_hold of this BusinessObjectFormat.  # noqa: E501
        :type: bool
        """

        self._legal_hold = legal_hold

    @property
    def retention_period_in_days(self):
        """Gets the retention_period_in_days of this BusinessObjectFormat.  # noqa: E501

        Retention period (in days) for business object data registered with this format.                  # noqa: E501

        :return: The retention_period_in_days of this BusinessObjectFormat.  # noqa: E501
        :rtype: int
        """
        return self._retention_period_in_days

    @retention_period_in_days.setter
    def retention_period_in_days(self, retention_period_in_days):
        """Sets the retention_period_in_days of this BusinessObjectFormat.

        Retention period (in days) for business object data registered with this format.                  # noqa: E501

        :param retention_period_in_days: The retention_period_in_days of this BusinessObjectFormat.  # noqa: E501
        :type: int
        """

        self._retention_period_in_days = retention_period_in_days

    @property
    def retention_type(self):
        """Gets the retention_type of this BusinessObjectFormat.  # noqa: E501

        Retention type. Supported retention types: PARTITION_VALUE, BDATA_RETENTION_TYPE.                  # noqa: E501

        :return: The retention_type of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._retention_type

    @retention_type.setter
    def retention_type(self, retention_type):
        """Sets the retention_type of this BusinessObjectFormat.

        Retention type. Supported retention types: PARTITION_VALUE, BDATA_RETENTION_TYPE.                  # noqa: E501

        :param retention_type: The retention_type of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """

        self._retention_type = retention_type

    @property
    def allow_non_backwards_compatible_changes(self):
        """Gets the allow_non_backwards_compatible_changes of this BusinessObjectFormat.  # noqa: E501

        If true, allows non backwards compatible changes to the schema                  # noqa: E501

        :return: The allow_non_backwards_compatible_changes of this BusinessObjectFormat.  # noqa: E501
        :rtype: bool
        """
        return self._allow_non_backwards_compatible_changes

    @allow_non_backwards_compatible_changes.setter
    def allow_non_backwards_compatible_changes(self, allow_non_backwards_compatible_changes):
        """Sets the allow_non_backwards_compatible_changes of this BusinessObjectFormat.

        If true, allows non backwards compatible changes to the schema                  # noqa: E501

        :param allow_non_backwards_compatible_changes: The allow_non_backwards_compatible_changes of this BusinessObjectFormat.  # noqa: E501
        :type: bool
        """

        self._allow_non_backwards_compatible_changes = allow_non_backwards_compatible_changes

    @property
    def relational_schema_name(self):
        """Gets the relational_schema_name of this BusinessObjectFormat.  # noqa: E501

        Contains Relational Schema Name if the Format is of type Relational Table  # noqa: E501

        :return: The relational_schema_name of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._relational_schema_name

    @relational_schema_name.setter
    def relational_schema_name(self, relational_schema_name):
        """Sets the relational_schema_name of this BusinessObjectFormat.

        Contains Relational Schema Name if the Format is of type Relational Table  # noqa: E501

        :param relational_schema_name: The relational_schema_name of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """

        self._relational_schema_name = relational_schema_name

    @property
    def relational_table_name(self):
        """Gets the relational_table_name of this BusinessObjectFormat.  # noqa: E501

        Contains Relational Table Name if the Format is of type Relational Table  # noqa: E501

        :return: The relational_table_name of this BusinessObjectFormat.  # noqa: E501
        :rtype: str
        """
        return self._relational_table_name

    @relational_table_name.setter
    def relational_table_name(self, relational_table_name):
        """Sets the relational_table_name of this BusinessObjectFormat.

        Contains Relational Table Name if the Format is of type Relational Table  # noqa: E501

        :param relational_table_name: The relational_table_name of this BusinessObjectFormat.  # noqa: E501
        :type: str
        """

        self._relational_table_name = relational_table_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.global_attribute_definition_api import GlobalAttributeDefinitionApi  # noqa: E501
from herdsdk.rest import ApiException


class TestGlobalAttributeDefinitionApi(unittest.TestCase):
    """GlobalAttributeDefinitionApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.global_attribute_definition_api.GlobalAttributeDefinitionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_global_attribute_definition_create_global_attribute_definition(self):
        """Test case for global_attribute_definition_create_global_attribute_definition

        createGlobalAttributeDefinition  # noqa: E501
        """
        pass

    def test_global_attribute_definition_delete_global_attribute_definition(self):
        """Test case for global_attribute_definition_delete_global_attribute_definition

        deleteGlobalAttributeDefinition  # noqa: E501
        """
        pass

    def test_global_attribute_definition_get_global_attribute_definition(self):
        """Test case for global_attribute_definition_get_global_attribute_definition

        getGlobalAttributeDefinition  # noqa: E501
        """
        pass

    def test_global_attribute_definition_get_global_attribute_definitions(self):
        """Test case for global_attribute_definition_get_global_attribute_definitions

        getGlobalAttributeDefinitions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class JobDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'namespace': 'str',
        'job_name': 'str',
        'description': 'str',
        'activiti_job_xml': 'str',
        'parameters': 'list[Parameter]',
        's3_properties_location': 'S3PropertiesLocation',
        'last_updated_by_user_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'namespace': 'namespace',
        'job_name': 'jobName',
        'description': 'description',
        'activiti_job_xml': 'activitiJobXml',
        'parameters': 'parameters',
        's3_properties_location': 's3PropertiesLocation',
        'last_updated_by_user_id': 'lastUpdatedByUserId'
    }

    def __init__(self, id=None, namespace=None, job_name=None, description=None, activiti_job_xml=None, parameters=None, s3_properties_location=None, last_updated_by_user_id=None):  # noqa: E501
        """JobDefinition - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._namespace = None
        self._job_name = None
        self._description = None
        self._activiti_job_xml = None
        self._parameters = None
        self._s3_properties_location = None
        self._last_updated_by_user_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.namespace = namespace
        self.job_name = job_name
        if description is not None:
            self.description = description
        self.activiti_job_xml = activiti_job_xml
        if parameters is not None:
            self.parameters = parameters
        if s3_properties_location is not None:
            self.s3_properties_location = s3_properties_location
        if last_updated_by_user_id is not None:
            self.last_updated_by_user_id = last_updated_by_user_id

    @property
    def id(self):
        """Gets the id of this JobDefinition.  # noqa: E501

        The internal identifier that uniquely references a job definition  # noqa: E501

        :return: The id of this JobDefinition.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobDefinition.

        The internal identifier that uniquely references a job definition  # noqa: E501

        :param id: The id of this JobDefinition.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def namespace(self):
        """Gets the namespace of this JobDefinition.  # noqa: E501

        The namespace of the job definition  # noqa: E501

        :return: The namespace of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this JobDefinition.

        The namespace of the job definition  # noqa: E501

        :param namespace: The namespace of this JobDefinition.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def job_name(self):
        """Gets the job_name of this JobDefinition.  # noqa: E501

        The name of the job definition  # noqa: E501

        :return: The job_name of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this JobDefinition.

        The name of the job definition  # noqa: E501

        :param job_name: The job_name of this JobDefinition.  # noqa: E501
        :type: str
        """
        if job_name is None:
            raise ValueError("Invalid value for `job_name`, must not be `None`")  # noqa: E501

        self._job_name = job_name

    @property
    def description(self):
        """Gets the description of this JobDefinition.  # noqa: E501

        Description of the job definition  # noqa: E501

        :return: The description of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this JobDefinition.

        Description of the job definition  # noqa: E501

        :param description: The description of this JobDefinition.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def activiti_job_xml(self):
        """Gets the activiti_job_xml of this JobDefinition.  # noqa: E501

        Activiti workflow XML related to the job  # noqa: E501

        :return: The activiti_job_xml of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._activiti_job_xml

    @activiti_job_xml.setter
    def activiti_job_xml(self, activiti_job_xml):
        """Sets the activiti_job_xml of this JobDefinition.

        Activiti workflow XML related to the job  # noqa: E501

        :param activiti_job_xml: The activiti_job_xml of this JobDefinition.  # noqa: E501
        :type: str
        """
        if activiti_job_xml is None:
            raise ValueError("Invalid value for `activiti_job_xml`, must not be `None`")  # noqa: E501

        self._activiti_job_xml = activiti_job_xml

    @property
    def parameters(self):
        """Gets the parameters of this JobDefinition.  # noqa: E501

        Default list of key/value pairs that will be made available to the job when it is executed. These values can be overridden by                   parameters                   specified during the job execution                  # noqa: E501

        :return: The parameters of this JobDefinition.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this JobDefinition.

        Default list of key/value pairs that will be made available to the job when it is executed. These values can be overridden by                   parameters                   specified during the job execution                  # noqa: E501

        :param parameters: The parameters of this JobDefinition.  # noqa: E501
        :type: list[Parameter]
        """

        self._parameters = parameters

    @property
    def s3_properties_location(self):
        """Gets the s3_properties_location of this JobDefinition.  # noqa: E501


        :return: The s3_properties_location of this JobDefinition.  # noqa: E501
        :rtype: S3PropertiesLocation
        """
        return self._s3_properties_location

    @s3_properties_location.setter
    def s3_properties_location(self, s3_properties_location):
        """Sets the s3_properties_location of this JobDefinition.


        :param s3_properties_location: The s3_properties_location of this JobDefinition.  # noqa: E501
        :type: S3PropertiesLocation
        """

        self._s3_properties_location = s3_properties_location

    @property
    def last_updated_by_user_id(self):
        """Gets the last_updated_by_user_id of this JobDefinition.  # noqa: E501

        The user ID under whose authorization context the workflow runs  # noqa: E501

        :return: The last_updated_by_user_id of this JobDefinition.  # noqa: E501
        :rtype: str
        """
        return self._last_updated_by_user_id

    @last_updated_by_user_id.setter
    def last_updated_by_user_id(self, last_updated_by_user_id):
        """Sets the last_updated_by_user_id of this JobDefinition.

        The user ID under whose authorization context the workflow runs  # noqa: E501

        :param last_updated_by_user_id: The last_updated_by_user_id of this JobDefinition.  # noqa: E501
        :type: str
        """

        self._last_updated_by_user_id = last_updated_by_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectFormatRetentionInformationUpdateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'record_flag': 'bool',
        'retention_period_in_days': 'int',
        'retention_type': 'str'
    }

    attribute_map = {
        'record_flag': 'recordFlag',
        'retention_period_in_days': 'retentionPeriodInDays',
        'retention_type': 'retentionType'
    }

    def __init__(self, record_flag=None, retention_period_in_days=None, retention_type=None):  # noqa: E501
        """BusinessObjectFormatRetentionInformationUpdateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._record_flag = None
        self._retention_period_in_days = None
        self._retention_type = None
        self.discriminator = None

        if record_flag is not None:
            self.record_flag = record_flag
        if retention_period_in_days is not None:
            self.retention_period_in_days = retention_period_in_days
        if retention_type is not None:
            self.retention_type = retention_type

    @property
    def record_flag(self):
        """Gets the record_flag of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501

        Indicates if business object data registered with this format is a record                  # noqa: E501

        :return: The record_flag of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._record_flag

    @record_flag.setter
    def record_flag(self, record_flag):
        """Sets the record_flag of this BusinessObjectFormatRetentionInformationUpdateRequest.

        Indicates if business object data registered with this format is a record                  # noqa: E501

        :param record_flag: The record_flag of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501
        :type: bool
        """

        self._record_flag = record_flag

    @property
    def retention_period_in_days(self):
        """Gets the retention_period_in_days of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501

        Retention period (in days) for business object data registered with this format. This value must only be specified for                   PARTITION_VALUE retention type                  # noqa: E501

        :return: The retention_period_in_days of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._retention_period_in_days

    @retention_period_in_days.setter
    def retention_period_in_days(self, retention_period_in_days):
        """Sets the retention_period_in_days of this BusinessObjectFormatRetentionInformationUpdateRequest.

        Retention period (in days) for business object data registered with this format. This value must only be specified for                   PARTITION_VALUE retention type                  # noqa: E501

        :param retention_period_in_days: The retention_period_in_days of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501
        :type: int
        """

        self._retention_period_in_days = retention_period_in_days

    @property
    def retention_type(self):
        """Gets the retention_type of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501

        Retention type. Supported retention types are: PARTITION_VALUE, BDATA_RETENTION_DATE                  # noqa: E501

        :return: The retention_type of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._retention_type

    @retention_type.setter
    def retention_type(self, retention_type):
        """Sets the retention_type of this BusinessObjectFormatRetentionInformationUpdateRequest.

        Retention type. Supported retention types are: PARTITION_VALUE, BDATA_RETENTION_DATE                  # noqa: E501

        :param retention_type: The retention_type of this BusinessObjectFormatRetentionInformationUpdateRequest.  # noqa: E501
        :type: str
        """

        self._retention_type = retention_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectFormatRetentionInformationUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class SecurityRoleToFunctionMappingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def security_role_to_function_mapping_create_security_role_function(self, security_role_function_create_request, **kwargs):  # noqa: E501
        """createSecurityRoleFunction  # noqa: E501

        Creates a new security role to function mapping that is identified by security role name and security function name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_create_security_role_function(security_role_function_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SecurityRoleFunctionCreateRequest security_role_function_create_request: the information needed to create a security role to function mapping (required)
        :return: SecurityRoleFunction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.security_role_to_function_mapping_create_security_role_function_with_http_info(security_role_function_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.security_role_to_function_mapping_create_security_role_function_with_http_info(security_role_function_create_request, **kwargs)  # noqa: E501
            return data

    def security_role_to_function_mapping_create_security_role_function_with_http_info(self, security_role_function_create_request, **kwargs):  # noqa: E501
        """createSecurityRoleFunction  # noqa: E501

        Creates a new security role to function mapping that is identified by security role name and security function name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_create_security_role_function_with_http_info(security_role_function_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SecurityRoleFunctionCreateRequest security_role_function_create_request: the information needed to create a security role to function mapping (required)
        :return: SecurityRoleFunction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['security_role_function_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_role_to_function_mapping_create_security_role_function" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'security_role_function_create_request' is set
        if ('security_role_function_create_request' not in local_var_params or
                local_var_params['security_role_function_create_request'] is None):
            raise ValueError("Missing the required parameter `security_role_function_create_request` when calling `security_role_to_function_mapping_create_security_role_function`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'security_role_function_create_request' in local_var_params:
            body_params = local_var_params['security_role_function_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/securityRoleFunctions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRoleFunction',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_role_to_function_mapping_delete_security_role_function(self, security_role_name, security_function_name, **kwargs):  # noqa: E501
        """deleteSecurityRoleFunction  # noqa: E501

        Deletes an existing security role to function mapping based on the specified parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_delete_security_role_function(security_role_name, security_function_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_role_name: the security role name (required)
        :param str security_function_name: the security function name (required)
        :return: SecurityRoleFunction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.security_role_to_function_mapping_delete_security_role_function_with_http_info(security_role_name, security_function_name, **kwargs)  # noqa: E501
        else:
            (data) = self.security_role_to_function_mapping_delete_security_role_function_with_http_info(security_role_name, security_function_name, **kwargs)  # noqa: E501
            return data

    def security_role_to_function_mapping_delete_security_role_function_with_http_info(self, security_role_name, security_function_name, **kwargs):  # noqa: E501
        """deleteSecurityRoleFunction  # noqa: E501

        Deletes an existing security role to function mapping based on the specified parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_delete_security_role_function_with_http_info(security_role_name, security_function_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_role_name: the security role name (required)
        :param str security_function_name: the security function name (required)
        :return: SecurityRoleFunction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['security_role_name', 'security_function_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_role_to_function_mapping_delete_security_role_function" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'security_role_name' is set
        if ('security_role_name' not in local_var_params or
                local_var_params['security_role_name'] is None):
            raise ValueError("Missing the required parameter `security_role_name` when calling `security_role_to_function_mapping_delete_security_role_function`")  # noqa: E501
        # verify the required parameter 'security_function_name' is set
        if ('security_function_name' not in local_var_params or
                local_var_params['security_function_name'] is None):
            raise ValueError("Missing the required parameter `security_function_name` when calling `security_role_to_function_mapping_delete_security_role_function`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'security_role_name' in local_var_params:
            path_params['securityRoleName'] = local_var_params['security_role_name']  # noqa: E501
        if 'security_function_name' in local_var_params:
            path_params['securityFunctionName'] = local_var_params['security_function_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/securityRoleFunctions/securityRoleNames/{securityRoleName}/securityFunctionNames/{securityFunctionName}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRoleFunction',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_role_to_function_mapping_get_security_role_function(self, security_role_name, security_function_name, **kwargs):  # noqa: E501
        """getSecurityRoleFunction  # noqa: E501

        Retrieves an existing security role to function mapping based on the specified parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_get_security_role_function(security_role_name, security_function_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_role_name: the security role name (required)
        :param str security_function_name: the security function name (required)
        :return: SecurityRoleFunction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.security_role_to_function_mapping_get_security_role_function_with_http_info(security_role_name, security_function_name, **kwargs)  # noqa: E501
        else:
            (data) = self.security_role_to_function_mapping_get_security_role_function_with_http_info(security_role_name, security_function_name, **kwargs)  # noqa: E501
            return data

    def security_role_to_function_mapping_get_security_role_function_with_http_info(self, security_role_name, security_function_name, **kwargs):  # noqa: E501
        """getSecurityRoleFunction  # noqa: E501

        Retrieves an existing security role to function mapping based on the specified parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_get_security_role_function_with_http_info(security_role_name, security_function_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_role_name: the security role name (required)
        :param str security_function_name: the security function name (required)
        :return: SecurityRoleFunction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['security_role_name', 'security_function_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_role_to_function_mapping_get_security_role_function" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'security_role_name' is set
        if ('security_role_name' not in local_var_params or
                local_var_params['security_role_name'] is None):
            raise ValueError("Missing the required parameter `security_role_name` when calling `security_role_to_function_mapping_get_security_role_function`")  # noqa: E501
        # verify the required parameter 'security_function_name' is set
        if ('security_function_name' not in local_var_params or
                local_var_params['security_function_name'] is None):
            raise ValueError("Missing the required parameter `security_function_name` when calling `security_role_to_function_mapping_get_security_role_function`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'security_role_name' in local_var_params:
            path_params['securityRoleName'] = local_var_params['security_role_name']  # noqa: E501
        if 'security_function_name' in local_var_params:
            path_params['securityFunctionName'] = local_var_params['security_function_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/securityRoleFunctions/securityRoleNames/{securityRoleName}/securityFunctionNames/{securityFunctionName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRoleFunction',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_role_to_function_mapping_get_security_role_functions(self, **kwargs):  # noqa: E501
        """getSecurityRoleFunctions  # noqa: E501

        Retrieves a list of security role to function mapping keys for all security role to function mappings registered in the system. The result list is sorted by security role name and security function name in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_get_security_role_functions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SecurityRoleFunctionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.security_role_to_function_mapping_get_security_role_functions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.security_role_to_function_mapping_get_security_role_functions_with_http_info(**kwargs)  # noqa: E501
            return data

    def security_role_to_function_mapping_get_security_role_functions_with_http_info(self, **kwargs):  # noqa: E501
        """getSecurityRoleFunctions  # noqa: E501

        Retrieves a list of security role to function mapping keys for all security role to function mappings registered in the system. The result list is sorted by security role name and security function name in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_get_security_role_functions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SecurityRoleFunctionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_role_to_function_mapping_get_security_role_functions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/securityRoleFunctions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRoleFunctionKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_role_to_function_mapping_get_security_role_functions_by_security_function(self, security_function_name, **kwargs):  # noqa: E501
        """getSecurityRoleFunctionsBySecurityFunction  # noqa: E501

        Retrieves a list of security role to function mapping keys for the specified security function. The result list is sorted by security role name in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_get_security_role_functions_by_security_function(security_function_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_function_name: the security function name (required)
        :return: SecurityRoleFunctionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.security_role_to_function_mapping_get_security_role_functions_by_security_function_with_http_info(security_function_name, **kwargs)  # noqa: E501
        else:
            (data) = self.security_role_to_function_mapping_get_security_role_functions_by_security_function_with_http_info(security_function_name, **kwargs)  # noqa: E501
            return data

    def security_role_to_function_mapping_get_security_role_functions_by_security_function_with_http_info(self, security_function_name, **kwargs):  # noqa: E501
        """getSecurityRoleFunctionsBySecurityFunction  # noqa: E501

        Retrieves a list of security role to function mapping keys for the specified security function. The result list is sorted by security role name in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_get_security_role_functions_by_security_function_with_http_info(security_function_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_function_name: the security function name (required)
        :return: SecurityRoleFunctionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['security_function_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_role_to_function_mapping_get_security_role_functions_by_security_function" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'security_function_name' is set
        if ('security_function_name' not in local_var_params or
                local_var_params['security_function_name'] is None):
            raise ValueError("Missing the required parameter `security_function_name` when calling `security_role_to_function_mapping_get_security_role_functions_by_security_function`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'security_function_name' in local_var_params:
            path_params['securityFunctionName'] = local_var_params['security_function_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/securityRoleFunctions/securityFunctionNames/{securityFunctionName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRoleFunctionKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def security_role_to_function_mapping_get_security_role_functions_by_security_role(self, security_role_name, **kwargs):  # noqa: E501
        """getSecurityRoleFunctionsBySecurityRole  # noqa: E501

        Retrieves a list of security role to function mapping keys for the specified security role. The result list is sorted by security function name in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_get_security_role_functions_by_security_role(security_role_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_role_name: the security role name (required)
        :return: SecurityRoleFunctionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.security_role_to_function_mapping_get_security_role_functions_by_security_role_with_http_info(security_role_name, **kwargs)  # noqa: E501
        else:
            (data) = self.security_role_to_function_mapping_get_security_role_functions_by_security_role_with_http_info(security_role_name, **kwargs)  # noqa: E501
            return data

    def security_role_to_function_mapping_get_security_role_functions_by_security_role_with_http_info(self, security_role_name, **kwargs):  # noqa: E501
        """getSecurityRoleFunctionsBySecurityRole  # noqa: E501

        Retrieves a list of security role to function mapping keys for the specified security role. The result list is sorted by security function name in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.security_role_to_function_mapping_get_security_role_functions_by_security_role_with_http_info(security_role_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_role_name: the security role name (required)
        :return: SecurityRoleFunctionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['security_role_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method security_role_to_function_mapping_get_security_role_functions_by_security_role" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'security_role_name' is set
        if ('security_role_name' not in local_var_params or
                local_var_params['security_role_name'] is None):
            raise ValueError("Missing the required parameter `security_role_name` when calling `security_role_to_function_mapping_get_security_role_functions_by_security_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'security_role_name' in local_var_params:
            path_params['securityRoleName'] = local_var_params['security_role_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/securityRoleFunctions/securityRoleNames/{securityRoleName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecurityRoleFunctionKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'partition_key': 'str',
        'partition_value': 'str',
        'sub_partition_values': 'list[str]',
        'version': 'int',
        'latest_version': 'bool',
        'status': 'str',
        'storage_units': 'list[StorageUnit]',
        'attributes': 'list[Attribute]',
        'business_object_data_parents': 'list[BusinessObjectDataKey]',
        'business_object_data_children': 'list[BusinessObjectDataKey]',
        'business_object_data_status_history': 'list[BusinessObjectDataStatusChangeEvent]',
        'legal_hold': 'bool',
        'retention_expiration_date': 'datetime',
        'created_by_user_id': 'str',
        'created_on': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'partition_key': 'partitionKey',
        'partition_value': 'partitionValue',
        'sub_partition_values': 'subPartitionValues',
        'version': 'version',
        'latest_version': 'latestVersion',
        'status': 'status',
        'storage_units': 'storageUnits',
        'attributes': 'attributes',
        'business_object_data_parents': 'businessObjectDataParents',
        'business_object_data_children': 'businessObjectDataChildren',
        'business_object_data_status_history': 'businessObjectDataStatusHistory',
        'legal_hold': 'legalHold',
        'retention_expiration_date': 'retentionExpirationDate',
        'created_by_user_id': 'createdByUserId',
        'created_on': 'createdOn'
    }

    def __init__(self, id=None, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, partition_key=None, partition_value=None, sub_partition_values=None, version=None, latest_version=None, status=None, storage_units=None, attributes=None, business_object_data_parents=None, business_object_data_children=None, business_object_data_status_history=None, legal_hold=None, retention_expiration_date=None, created_by_user_id=None, created_on=None):  # noqa: E501
        """BusinessObjectData - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._partition_key = None
        self._partition_value = None
        self._sub_partition_values = None
        self._version = None
        self._latest_version = None
        self._status = None
        self._storage_units = None
        self._attributes = None
        self._business_object_data_parents = None
        self._business_object_data_children = None
        self._business_object_data_status_history = None
        self._legal_hold = None
        self._retention_expiration_date = None
        self._created_by_user_id = None
        self._created_on = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        self.partition_key = partition_key
        self.partition_value = partition_value
        if sub_partition_values is not None:
            self.sub_partition_values = sub_partition_values
        if version is not None:
            self.version = version
        if latest_version is not None:
            self.latest_version = latest_version
        if status is not None:
            self.status = status
        if storage_units is not None:
            self.storage_units = storage_units
        if attributes is not None:
            self.attributes = attributes
        if business_object_data_parents is not None:
            self.business_object_data_parents = business_object_data_parents
        if business_object_data_children is not None:
            self.business_object_data_children = business_object_data_children
        if business_object_data_status_history is not None:
            self.business_object_data_status_history = business_object_data_status_history
        if legal_hold is not None:
            self.legal_hold = legal_hold
        if retention_expiration_date is not None:
            self.retention_expiration_date = retention_expiration_date
        if created_by_user_id is not None:
            self.created_by_user_id = created_by_user_id
        if created_on is not None:
            self.created_on = created_on

    @property
    def id(self):
        """Gets the id of this BusinessObjectData.  # noqa: E501

        The internal Id that uniquely references the newly created Business Object Data  # noqa: E501

        :return: The id of this BusinessObjectData.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BusinessObjectData.

        The internal Id that uniquely references the newly created Business Object Data  # noqa: E501

        :param id: The id of this BusinessObjectData.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectData.  # noqa: E501

        The Namespace to which a Business Object Format is related  # noqa: E501

        :return: The namespace of this BusinessObjectData.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectData.

        The Namespace to which a Business Object Format is related  # noqa: E501

        :param namespace: The namespace of this BusinessObjectData.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectData.  # noqa: E501

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectData.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectData.

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectData.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectData.  # noqa: E501

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :return: The business_object_format_usage of this BusinessObjectData.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectData.

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectData.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectData.  # noqa: E501

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :return: The business_object_format_file_type of this BusinessObjectData.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectData.

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectData.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectData.  # noqa: E501

        The Business Object Format Version for a previously registered Business Object Format  # noqa: E501

        :return: The business_object_format_version of this BusinessObjectData.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectData.

        The Business Object Format Version for a previously registered Business Object Format  # noqa: E501

        :param business_object_format_version: The business_object_format_version of this BusinessObjectData.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def partition_key(self):
        """Gets the partition_key of this BusinessObjectData.  # noqa: E501

        The Partition Key this Business Object Data is being registered with. This must be they Partition Key specified in the Business                   Object Format                  # noqa: E501

        :return: The partition_key of this BusinessObjectData.  # noqa: E501
        :rtype: str
        """
        return self._partition_key

    @partition_key.setter
    def partition_key(self, partition_key):
        """Sets the partition_key of this BusinessObjectData.

        The Partition Key this Business Object Data is being registered with. This must be they Partition Key specified in the Business                   Object Format                  # noqa: E501

        :param partition_key: The partition_key of this BusinessObjectData.  # noqa: E501
        :type: str
        """
        if partition_key is None:
            raise ValueError("Invalid value for `partition_key`, must not be `None`")  # noqa: E501

        self._partition_key = partition_key

    @property
    def partition_value(self):
        """Gets the partition_value of this BusinessObjectData.  # noqa: E501

        The Partition Value that this Business Object Data is associated with  # noqa: E501

        :return: The partition_value of this BusinessObjectData.  # noqa: E501
        :rtype: str
        """
        return self._partition_value

    @partition_value.setter
    def partition_value(self, partition_value):
        """Sets the partition_value of this BusinessObjectData.

        The Partition Value that this Business Object Data is associated with  # noqa: E501

        :param partition_value: The partition_value of this BusinessObjectData.  # noqa: E501
        :type: str
        """
        if partition_value is None:
            raise ValueError("Invalid value for `partition_value`, must not be `None`")  # noqa: E501

        self._partition_value = partition_value

    @property
    def sub_partition_values(self):
        """Gets the sub_partition_values of this BusinessObjectData.  # noqa: E501

        A list of Sub-Partition values associated with this Business Object Data  # noqa: E501

        :return: The sub_partition_values of this BusinessObjectData.  # noqa: E501
        :rtype: list[str]
        """
        return self._sub_partition_values

    @sub_partition_values.setter
    def sub_partition_values(self, sub_partition_values):
        """Sets the sub_partition_values of this BusinessObjectData.

        A list of Sub-Partition values associated with this Business Object Data  # noqa: E501

        :param sub_partition_values: The sub_partition_values of this BusinessObjectData.  # noqa: E501
        :type: list[str]
        """

        self._sub_partition_values = sub_partition_values

    @property
    def version(self):
        """Gets the version of this BusinessObjectData.  # noqa: E501

        The numeric version of a Business Object Data. Each time a new data object is registered, the new version will be the previous                   version + 1                  # noqa: E501

        :return: The version of this BusinessObjectData.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BusinessObjectData.

        The numeric version of a Business Object Data. Each time a new data object is registered, the new version will be the previous                   version + 1                  # noqa: E501

        :param version: The version of this BusinessObjectData.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def latest_version(self):
        """Gets the latest_version of this BusinessObjectData.  # noqa: E501

        *No longer in use* A boolean flag that shows whether this instance of data is the latest or not. Once a new version of data is                   registered, any previous versions will no longer be the latest                  # noqa: E501

        :return: The latest_version of this BusinessObjectData.  # noqa: E501
        :rtype: bool
        """
        return self._latest_version

    @latest_version.setter
    def latest_version(self, latest_version):
        """Sets the latest_version of this BusinessObjectData.

        *No longer in use* A boolean flag that shows whether this instance of data is the latest or not. Once a new version of data is                   registered, any previous versions will no longer be the latest                  # noqa: E501

        :param latest_version: The latest_version of this BusinessObjectData.  # noqa: E501
        :type: bool
        """

        self._latest_version = latest_version

    @property
    def status(self):
        """Gets the status of this BusinessObjectData.  # noqa: E501

        The status of the Business Object Data. One of the following values: VALID, UPLOADING, PENDING_VALID, PROCESSING, INVALID,                   ARCHIVED, EXPIRED, or DELETED                  # noqa: E501

        :return: The status of this BusinessObjectData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BusinessObjectData.

        The status of the Business Object Data. One of the following values: VALID, UPLOADING, PENDING_VALID, PROCESSING, INVALID,                   ARCHIVED, EXPIRED, or DELETED                  # noqa: E501

        :param status: The status of this BusinessObjectData.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def storage_units(self):
        """Gets the storage_units of this BusinessObjectData.  # noqa: E501

        A container for the Storage Units associated with a Business Object Data  # noqa: E501

        :return: The storage_units of this BusinessObjectData.  # noqa: E501
        :rtype: list[StorageUnit]
        """
        return self._storage_units

    @storage_units.setter
    def storage_units(self, storage_units):
        """Sets the storage_units of this BusinessObjectData.

        A container for the Storage Units associated with a Business Object Data  # noqa: E501

        :param storage_units: The storage_units of this BusinessObjectData.  # noqa: E501
        :type: list[StorageUnit]
        """

        self._storage_units = storage_units

    @property
    def attributes(self):
        """Gets the attributes of this BusinessObjectData.  # noqa: E501

        Collection of name-value pairs. This can be used to store things such as S3 bucket names, validation flags, and custom                   user-defined meta-data about this storage. Attributes values are required for certain keys that are defined as Attribute Definitions in the                   Business Object Format                  # noqa: E501

        :return: The attributes of this BusinessObjectData.  # noqa: E501
        :rtype: list[Attribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this BusinessObjectData.

        Collection of name-value pairs. This can be used to store things such as S3 bucket names, validation flags, and custom                   user-defined meta-data about this storage. Attributes values are required for certain keys that are defined as Attribute Definitions in the                   Business Object Format                  # noqa: E501

        :param attributes: The attributes of this BusinessObjectData.  # noqa: E501
        :type: list[Attribute]
        """

        self._attributes = attributes

    @property
    def business_object_data_parents(self):
        """Gets the business_object_data_parents of this BusinessObjectData.  # noqa: E501

        A list of Business Object Data parents (i.e. predecessors) that were used/needed in the creation of this data. This is used for                   data lineage. Each parent consists of the key data that uniquely defines a reference to a single Business Object Data.                  # noqa: E501

        :return: The business_object_data_parents of this BusinessObjectData.  # noqa: E501
        :rtype: list[BusinessObjectDataKey]
        """
        return self._business_object_data_parents

    @business_object_data_parents.setter
    def business_object_data_parents(self, business_object_data_parents):
        """Sets the business_object_data_parents of this BusinessObjectData.

        A list of Business Object Data parents (i.e. predecessors) that were used/needed in the creation of this data. This is used for                   data lineage. Each parent consists of the key data that uniquely defines a reference to a single Business Object Data.                  # noqa: E501

        :param business_object_data_parents: The business_object_data_parents of this BusinessObjectData.  # noqa: E501
        :type: list[BusinessObjectDataKey]
        """

        self._business_object_data_parents = business_object_data_parents

    @property
    def business_object_data_children(self):
        """Gets the business_object_data_children of this BusinessObjectData.  # noqa: E501

        A list of Business Object Data children that were creation from this data. This is used for data lineage. Each child consists                   of the key data that uniquely defines a reference to a single Business Object Data.                  # noqa: E501

        :return: The business_object_data_children of this BusinessObjectData.  # noqa: E501
        :rtype: list[BusinessObjectDataKey]
        """
        return self._business_object_data_children

    @business_object_data_children.setter
    def business_object_data_children(self, business_object_data_children):
        """Sets the business_object_data_children of this BusinessObjectData.

        A list of Business Object Data children that were creation from this data. This is used for data lineage. Each child consists                   of the key data that uniquely defines a reference to a single Business Object Data.                  # noqa: E501

        :param business_object_data_children: The business_object_data_children of this BusinessObjectData.  # noqa: E501
        :type: list[BusinessObjectDataKey]
        """

        self._business_object_data_children = business_object_data_children

    @property
    def business_object_data_status_history(self):
        """Gets the business_object_data_status_history of this BusinessObjectData.  # noqa: E501

        Lists all business object data status change events for this business object data  # noqa: E501

        :return: The business_object_data_status_history of this BusinessObjectData.  # noqa: E501
        :rtype: list[BusinessObjectDataStatusChangeEvent]
        """
        return self._business_object_data_status_history

    @business_object_data_status_history.setter
    def business_object_data_status_history(self, business_object_data_status_history):
        """Sets the business_object_data_status_history of this BusinessObjectData.

        Lists all business object data status change events for this business object data  # noqa: E501

        :param business_object_data_status_history: The business_object_data_status_history of this BusinessObjectData.  # noqa: E501
        :type: list[BusinessObjectDataStatusChangeEvent]
        """

        self._business_object_data_status_history = business_object_data_status_history

    @property
    def legal_hold(self):
        """Gets the legal_hold of this BusinessObjectData.  # noqa: E501

        Indicate if this Business Object Data is under legal hold  # noqa: E501

        :return: The legal_hold of this BusinessObjectData.  # noqa: E501
        :rtype: bool
        """
        return self._legal_hold

    @legal_hold.setter
    def legal_hold(self, legal_hold):
        """Sets the legal_hold of this BusinessObjectData.

        Indicate if this Business Object Data is under legal hold  # noqa: E501

        :param legal_hold: The legal_hold of this BusinessObjectData.  # noqa: E501
        :type: bool
        """

        self._legal_hold = legal_hold

    @property
    def retention_expiration_date(self):
        """Gets the retention_expiration_date of this BusinessObjectData.  # noqa: E501

        The retention expiration date for this business object data  # noqa: E501

        :return: The retention_expiration_date of this BusinessObjectData.  # noqa: E501
        :rtype: datetime
        """
        return self._retention_expiration_date

    @retention_expiration_date.setter
    def retention_expiration_date(self, retention_expiration_date):
        """Sets the retention_expiration_date of this BusinessObjectData.

        The retention expiration date for this business object data  # noqa: E501

        :param retention_expiration_date: The retention_expiration_date of this BusinessObjectData.  # noqa: E501
        :type: datetime
        """

        self._retention_expiration_date = retention_expiration_date

    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this BusinessObjectData.  # noqa: E501

        The User ID of the user who created this business object data  # noqa: E501

        :return: The created_by_user_id of this BusinessObjectData.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this BusinessObjectData.

        The User ID of the user who created this business object data  # noqa: E501

        :param created_by_user_id: The created_by_user_id of this BusinessObjectData.  # noqa: E501
        :type: str
        """

        self._created_by_user_id = created_by_user_id

    @property
    def created_on(self):
        """Gets the created_on of this BusinessObjectData.  # noqa: E501

        The timestamp when this business object data was created on  # noqa: E501

        :return: The created_on of this BusinessObjectData.  # noqa: E501
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this BusinessObjectData.

        The timestamp when this business object data was created on  # noqa: E501

        :param created_on: The created_on of this BusinessObjectData.  # noqa: E501
        :type: datetime
        """

        self._created_on = created_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.user_namespace_authorization_api import UserNamespaceAuthorizationApi  # noqa: E501
from herdsdk.rest import ApiException


class TestUserNamespaceAuthorizationApi(unittest.TestCase):
    """UserNamespaceAuthorizationApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.user_namespace_authorization_api.UserNamespaceAuthorizationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_namespace_authorization_create_user_namespace_authorization(self):
        """Test case for user_namespace_authorization_create_user_namespace_authorization

        createUserNamespaceAuthorization  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_delete_user_namespace_authorization(self):
        """Test case for user_namespace_authorization_delete_user_namespace_authorization

        deleteUserNamespaceAuthorization  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_delete_user_namespace_authorizations_by_user_id(self):
        """Test case for user_namespace_authorization_delete_user_namespace_authorizations_by_user_id

        deleteUserNamespaceAuthorizationsByUserId  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_get_user_namespace_authorization(self):
        """Test case for user_namespace_authorization_get_user_namespace_authorization

        getUserNamespaceAuthorization  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_get_user_namespace_authorizations_by_namespace(self):
        """Test case for user_namespace_authorization_get_user_namespace_authorizations_by_namespace

        getUserNamespaceAuthorizationsByNamespace  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_get_user_namespace_authorizations_by_user_id(self):
        """Test case for user_namespace_authorization_get_user_namespace_authorizations_by_user_id

        getUserNamespaceAuthorizationsByUserId  # noqa: E501
        """
        pass

    def test_user_namespace_authorization_update_user_namespace_authorization(self):
        """Test case for user_namespace_authorization_update_user_namespace_authorization

        updateUserNamespaceAuthorization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class SearchIndex(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'search_index_key': 'SearchIndexKey',
        'search_index_type': 'str',
        'search_index_status': 'str',
        'active': 'bool',
        'search_index_statistics': 'SearchIndexStatistics',
        'created_by_user_id': 'str',
        'created_on': 'datetime',
        'last_updated_on': 'datetime'
    }

    attribute_map = {
        'search_index_key': 'searchIndexKey',
        'search_index_type': 'searchIndexType',
        'search_index_status': 'searchIndexStatus',
        'active': 'active',
        'search_index_statistics': 'searchIndexStatistics',
        'created_by_user_id': 'createdByUserId',
        'created_on': 'createdOn',
        'last_updated_on': 'lastUpdatedOn'
    }

    def __init__(self, search_index_key=None, search_index_type=None, search_index_status=None, active=None, search_index_statistics=None, created_by_user_id=None, created_on=None, last_updated_on=None):  # noqa: E501
        """SearchIndex - a model defined in OpenAPI"""  # noqa: E501

        self._search_index_key = None
        self._search_index_type = None
        self._search_index_status = None
        self._active = None
        self._search_index_statistics = None
        self._created_by_user_id = None
        self._created_on = None
        self._last_updated_on = None
        self.discriminator = None

        self.search_index_key = search_index_key
        self.search_index_type = search_index_type
        self.search_index_status = search_index_status
        if active is not None:
            self.active = active
        if search_index_statistics is not None:
            self.search_index_statistics = search_index_statistics
        if created_by_user_id is not None:
            self.created_by_user_id = created_by_user_id
        if created_on is not None:
            self.created_on = created_on
        if last_updated_on is not None:
            self.last_updated_on = last_updated_on

    @property
    def search_index_key(self):
        """Gets the search_index_key of this SearchIndex.  # noqa: E501


        :return: The search_index_key of this SearchIndex.  # noqa: E501
        :rtype: SearchIndexKey
        """
        return self._search_index_key

    @search_index_key.setter
    def search_index_key(self, search_index_key):
        """Sets the search_index_key of this SearchIndex.


        :param search_index_key: The search_index_key of this SearchIndex.  # noqa: E501
        :type: SearchIndexKey
        """
        if search_index_key is None:
            raise ValueError("Invalid value for `search_index_key`, must not be `None`")  # noqa: E501

        self._search_index_key = search_index_key

    @property
    def search_index_type(self):
        """Gets the search_index_type of this SearchIndex.  # noqa: E501

        The type of this Search Index. One of the following values: BUS_OBJCT_DFNTN, TAG  # noqa: E501

        :return: The search_index_type of this SearchIndex.  # noqa: E501
        :rtype: str
        """
        return self._search_index_type

    @search_index_type.setter
    def search_index_type(self, search_index_type):
        """Sets the search_index_type of this SearchIndex.

        The type of this Search Index. One of the following values: BUS_OBJCT_DFNTN, TAG  # noqa: E501

        :param search_index_type: The search_index_type of this SearchIndex.  # noqa: E501
        :type: str
        """
        if search_index_type is None:
            raise ValueError("Invalid value for `search_index_type`, must not be `None`")  # noqa: E501

        self._search_index_type = search_index_type

    @property
    def search_index_status(self):
        """Gets the search_index_status of this SearchIndex.  # noqa: E501

        The status of this Search Index. One of the following values: BUILDING, READY  # noqa: E501

        :return: The search_index_status of this SearchIndex.  # noqa: E501
        :rtype: str
        """
        return self._search_index_status

    @search_index_status.setter
    def search_index_status(self, search_index_status):
        """Sets the search_index_status of this SearchIndex.

        The status of this Search Index. One of the following values: BUILDING, READY  # noqa: E501

        :param search_index_status: The search_index_status of this SearchIndex.  # noqa: E501
        :type: str
        """
        if search_index_status is None:
            raise ValueError("Invalid value for `search_index_status`, must not be `None`")  # noqa: E501

        self._search_index_status = search_index_status

    @property
    def active(self):
        """Gets the active of this SearchIndex.  # noqa: E501

        A flag to indicate if the index is active or not. If the index is active it will be included in the search results.                  # noqa: E501

        :return: The active of this SearchIndex.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this SearchIndex.

        A flag to indicate if the index is active or not. If the index is active it will be included in the search results.                  # noqa: E501

        :param active: The active of this SearchIndex.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def search_index_statistics(self):
        """Gets the search_index_statistics of this SearchIndex.  # noqa: E501


        :return: The search_index_statistics of this SearchIndex.  # noqa: E501
        :rtype: SearchIndexStatistics
        """
        return self._search_index_statistics

    @search_index_statistics.setter
    def search_index_statistics(self, search_index_statistics):
        """Sets the search_index_statistics of this SearchIndex.


        :param search_index_statistics: The search_index_statistics of this SearchIndex.  # noqa: E501
        :type: SearchIndexStatistics
        """

        self._search_index_statistics = search_index_statistics

    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this SearchIndex.  # noqa: E501

        The User ID of the user who created this Search Index  # noqa: E501

        :return: The created_by_user_id of this SearchIndex.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this SearchIndex.

        The User ID of the user who created this Search Index  # noqa: E501

        :param created_by_user_id: The created_by_user_id of this SearchIndex.  # noqa: E501
        :type: str
        """

        self._created_by_user_id = created_by_user_id

    @property
    def created_on(self):
        """Gets the created_on of this SearchIndex.  # noqa: E501

        The timestamp when this Search Index was created on  # noqa: E501

        :return: The created_on of this SearchIndex.  # noqa: E501
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SearchIndex.

        The timestamp when this Search Index was created on  # noqa: E501

        :param created_on: The created_on of this SearchIndex.  # noqa: E501
        :type: datetime
        """

        self._created_on = created_on

    @property
    def last_updated_on(self):
        """Gets the last_updated_on of this SearchIndex.  # noqa: E501

        The timestamp when this Search Index was last updated on  # noqa: E501

        :return: The last_updated_on of this SearchIndex.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated_on

    @last_updated_on.setter
    def last_updated_on(self, last_updated_on):
        """Sets the last_updated_on of this SearchIndex.

        The timestamp when this Search Index was last updated on  # noqa: E501

        :param last_updated_on: The last_updated_on of this SearchIndex.  # noqa: E501
        :type: datetime
        """

        self._last_updated_on = last_updated_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchIndex):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterDefinitionKerberosAttributes(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ad_domain_join_password': 'str',
        'ad_domain_join_user': 'str',
        'cross_realm_trust_principal_password': 'str',
        'kdc_admin_password': 'str',
        'realm': 'str'
    }

    attribute_map = {
        'ad_domain_join_password': 'adDomainJoinPassword',
        'ad_domain_join_user': 'adDomainJoinUser',
        'cross_realm_trust_principal_password': 'crossRealmTrustPrincipalPassword',
        'kdc_admin_password': 'kdcAdminPassword',
        'realm': 'realm'
    }

    def __init__(self, ad_domain_join_password=None, ad_domain_join_user=None, cross_realm_trust_principal_password=None, kdc_admin_password=None, realm=None):  # noqa: E501
        """EmrClusterDefinitionKerberosAttributes - a model defined in OpenAPI"""  # noqa: E501

        self._ad_domain_join_password = None
        self._ad_domain_join_user = None
        self._cross_realm_trust_principal_password = None
        self._kdc_admin_password = None
        self._realm = None
        self.discriminator = None

        if ad_domain_join_password is not None:
            self.ad_domain_join_password = ad_domain_join_password
        if ad_domain_join_user is not None:
            self.ad_domain_join_user = ad_domain_join_user
        if cross_realm_trust_principal_password is not None:
            self.cross_realm_trust_principal_password = cross_realm_trust_principal_password
        if kdc_admin_password is not None:
            self.kdc_admin_password = kdc_admin_password
        if realm is not None:
            self.realm = realm

    @property
    def ad_domain_join_password(self):
        """Gets the ad_domain_join_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501


        :return: The ad_domain_join_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :rtype: str
        """
        return self._ad_domain_join_password

    @ad_domain_join_password.setter
    def ad_domain_join_password(self, ad_domain_join_password):
        """Sets the ad_domain_join_password of this EmrClusterDefinitionKerberosAttributes.


        :param ad_domain_join_password: The ad_domain_join_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :type: str
        """

        self._ad_domain_join_password = ad_domain_join_password

    @property
    def ad_domain_join_user(self):
        """Gets the ad_domain_join_user of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501


        :return: The ad_domain_join_user of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :rtype: str
        """
        return self._ad_domain_join_user

    @ad_domain_join_user.setter
    def ad_domain_join_user(self, ad_domain_join_user):
        """Sets the ad_domain_join_user of this EmrClusterDefinitionKerberosAttributes.


        :param ad_domain_join_user: The ad_domain_join_user of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :type: str
        """

        self._ad_domain_join_user = ad_domain_join_user

    @property
    def cross_realm_trust_principal_password(self):
        """Gets the cross_realm_trust_principal_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501

        Required only when establishing a cross-realm trust with a KDC in a different realm  # noqa: E501

        :return: The cross_realm_trust_principal_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :rtype: str
        """
        return self._cross_realm_trust_principal_password

    @cross_realm_trust_principal_password.setter
    def cross_realm_trust_principal_password(self, cross_realm_trust_principal_password):
        """Sets the cross_realm_trust_principal_password of this EmrClusterDefinitionKerberosAttributes.

        Required only when establishing a cross-realm trust with a KDC in a different realm  # noqa: E501

        :param cross_realm_trust_principal_password: The cross_realm_trust_principal_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :type: str
        """

        self._cross_realm_trust_principal_password = cross_realm_trust_principal_password

    @property
    def kdc_admin_password(self):
        """Gets the kdc_admin_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501

        The password used within the cluster for the kadmin service on the cluster-dedicated KDC, which maintains Kerberos principals,                   password policies, and keytabs for the cluster                  # noqa: E501

        :return: The kdc_admin_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :rtype: str
        """
        return self._kdc_admin_password

    @kdc_admin_password.setter
    def kdc_admin_password(self, kdc_admin_password):
        """Sets the kdc_admin_password of this EmrClusterDefinitionKerberosAttributes.

        The password used within the cluster for the kadmin service on the cluster-dedicated KDC, which maintains Kerberos principals,                   password policies, and keytabs for the cluster                  # noqa: E501

        :param kdc_admin_password: The kdc_admin_password of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :type: str
        """

        self._kdc_admin_password = kdc_admin_password

    @property
    def realm(self):
        """Gets the realm of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501

        The name of the Kerberos realm to which all nodes in a cluster belong  # noqa: E501

        :return: The realm of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :rtype: str
        """
        return self._realm

    @realm.setter
    def realm(self, realm):
        """Sets the realm of this EmrClusterDefinitionKerberosAttributes.

        The name of the Kerberos realm to which all nodes in a cluster belong  # noqa: E501

        :param realm: The realm of this EmrClusterDefinitionKerberosAttributes.  # noqa: E501
        :type: str
        """

        self._realm = realm

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterDefinitionKerberosAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class JdbcConnection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'username': 'str',
        'password': 'str',
        'database_type': 'str'
    }

    attribute_map = {
        'url': 'url',
        'username': 'username',
        'password': 'password',
        'database_type': 'databaseType'
    }

    def __init__(self, url=None, username=None, password=None, database_type=None):  # noqa: E501
        """JdbcConnection - a model defined in OpenAPI"""  # noqa: E501

        self._url = None
        self._username = None
        self._password = None
        self._database_type = None
        self.discriminator = None

        self.url = url
        self.username = username
        self.password = password
        self.database_type = database_type

    @property
    def url(self):
        """Gets the url of this JdbcConnection.  # noqa: E501


        :return: The url of this JdbcConnection.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this JdbcConnection.


        :param url: The url of this JdbcConnection.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def username(self):
        """Gets the username of this JdbcConnection.  # noqa: E501


        :return: The username of this JdbcConnection.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this JdbcConnection.


        :param username: The username of this JdbcConnection.  # noqa: E501
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def password(self):
        """Gets the password of this JdbcConnection.  # noqa: E501


        :return: The password of this JdbcConnection.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this JdbcConnection.


        :param password: The password of this JdbcConnection.  # noqa: E501
        :type: str
        """
        if password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def database_type(self):
        """Gets the database_type of this JdbcConnection.  # noqa: E501


        :return: The database_type of this JdbcConnection.  # noqa: E501
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """Sets the database_type of this JdbcConnection.


        :param database_type: The database_type of this JdbcConnection.  # noqa: E501
        :type: str
        """
        if database_type is None:
            raise ValueError("Invalid value for `database_type`, must not be `None`")  # noqa: E501
        allowed_values = ["ORACLE", "POSTGRES", "REDSHIFT", "MYSQL"]  # noqa: E501
        if database_type not in allowed_values:
            raise ValueError(
                "Invalid value for `database_type` ({0}), must be one of {1}"  # noqa: E501
                .format(database_type, allowed_values)
            )

        self._database_type = database_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JdbcConnection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_definition_column_api import BusinessObjectDefinitionColumnApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDefinitionColumnApi(unittest.TestCase):
    """BusinessObjectDefinitionColumnApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_definition_column_api.BusinessObjectDefinitionColumnApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_definition_column_create_business_object_definition_column(self):
        """Test case for business_object_definition_column_create_business_object_definition_column

        createBusinessObjectDefinitionColumn  # noqa: E501
        """
        pass

    def test_business_object_definition_column_delete_business_object_definition_column(self):
        """Test case for business_object_definition_column_delete_business_object_definition_column

        deleteBusinessObjectDefinitionColumn  # noqa: E501
        """
        pass

    def test_business_object_definition_column_get_business_object_definition_column(self):
        """Test case for business_object_definition_column_get_business_object_definition_column

        getBusinessObjectDefinitionColumn  # noqa: E501
        """
        pass

    def test_business_object_definition_column_get_business_object_definition_columns(self):
        """Test case for business_object_definition_column_get_business_object_definition_columns

        getBusinessObjectDefinitionColumns  # noqa: E501
        """
        pass

    def test_business_object_definition_column_search_business_object_definition_columns(self):
        """Test case for business_object_definition_column_search_business_object_definition_columns

        searchBusinessObjectDefinitionColumns  # noqa: E501
        """
        pass

    def test_business_object_definition_column_update_business_object_definition_column(self):
        """Test case for business_object_definition_column_update_business_object_definition_column

        updateBusinessObjectDefinitionColumn  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterDefinitionCapacityReservationOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'usage_strategy': 'str',
        'capacity_reservation_preference': 'str',
        'capacity_reservation_resource_group_arn': 'str'
    }

    attribute_map = {
        'usage_strategy': 'usageStrategy',
        'capacity_reservation_preference': 'capacityReservationPreference',
        'capacity_reservation_resource_group_arn': 'capacityReservationResourceGroupArn'
    }

    def __init__(self, usage_strategy=None, capacity_reservation_preference=None, capacity_reservation_resource_group_arn=None):  # noqa: E501
        """EmrClusterDefinitionCapacityReservationOptions - a model defined in OpenAPI"""  # noqa: E501

        self._usage_strategy = None
        self._capacity_reservation_preference = None
        self._capacity_reservation_resource_group_arn = None
        self.discriminator = None

        if usage_strategy is not None:
            self.usage_strategy = usage_strategy
        if capacity_reservation_preference is not None:
            self.capacity_reservation_preference = capacity_reservation_preference
        if capacity_reservation_resource_group_arn is not None:
            self.capacity_reservation_resource_group_arn = capacity_reservation_resource_group_arn

    @property
    def usage_strategy(self):
        """Gets the usage_strategy of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501

        Indicates whether to use unused Capacity Reservations for fulfilling On-Demand capacity                  # noqa: E501

        :return: The usage_strategy of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501
        :rtype: str
        """
        return self._usage_strategy

    @usage_strategy.setter
    def usage_strategy(self, usage_strategy):
        """Sets the usage_strategy of this EmrClusterDefinitionCapacityReservationOptions.

        Indicates whether to use unused Capacity Reservations for fulfilling On-Demand capacity                  # noqa: E501

        :param usage_strategy: The usage_strategy of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501
        :type: str
        """

        self._usage_strategy = usage_strategy

    @property
    def capacity_reservation_preference(self):
        """Gets the capacity_reservation_preference of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501

        Indicates the instance's Capacity Reservation preferences                  # noqa: E501

        :return: The capacity_reservation_preference of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501
        :rtype: str
        """
        return self._capacity_reservation_preference

    @capacity_reservation_preference.setter
    def capacity_reservation_preference(self, capacity_reservation_preference):
        """Sets the capacity_reservation_preference of this EmrClusterDefinitionCapacityReservationOptions.

        Indicates the instance's Capacity Reservation preferences                  # noqa: E501

        :param capacity_reservation_preference: The capacity_reservation_preference of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501
        :type: str
        """

        self._capacity_reservation_preference = capacity_reservation_preference

    @property
    def capacity_reservation_resource_group_arn(self):
        """Gets the capacity_reservation_resource_group_arn of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501

        The ARN of the Capacity Reservation resource group in which to run the instance                  # noqa: E501

        :return: The capacity_reservation_resource_group_arn of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501
        :rtype: str
        """
        return self._capacity_reservation_resource_group_arn

    @capacity_reservation_resource_group_arn.setter
    def capacity_reservation_resource_group_arn(self, capacity_reservation_resource_group_arn):
        """Sets the capacity_reservation_resource_group_arn of this EmrClusterDefinitionCapacityReservationOptions.

        The ARN of the Capacity Reservation resource group in which to run the instance                  # noqa: E501

        :param capacity_reservation_resource_group_arn: The capacity_reservation_resource_group_arn of this EmrClusterDefinitionCapacityReservationOptions.  # noqa: E501
        :type: str
        """

        self._capacity_reservation_resource_group_arn = capacity_reservation_resource_group_arn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterDefinitionCapacityReservationOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.security_role_api import SecurityRoleApi  # noqa: E501
from herdsdk.rest import ApiException


class TestSecurityRoleApi(unittest.TestCase):
    """SecurityRoleApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.security_role_api.SecurityRoleApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_security_role_create_security_role(self):
        """Test case for security_role_create_security_role

        createSecurityRole  # noqa: E501
        """
        pass

    def test_security_role_delete_security_role(self):
        """Test case for security_role_delete_security_role

        deleteSecurityRole  # noqa: E501
        """
        pass

    def test_security_role_get_security_role(self):
        """Test case for security_role_get_security_role

        getSecurityRole  # noqa: E501
        """
        pass

    def test_security_role_get_security_roles(self):
        """Test case for security_role_get_security_roles

        getSecurityRoles  # noqa: E501
        """
        pass

    def test_security_role_update_security_role(self):
        """Test case for security_role_update_security_role

        updateSecurityRole  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class JobApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def job_create_job(self, job_create_request, **kwargs):  # noqa: E501
        """createJob  # noqa: E501

        Creates and starts a new job asynchronously. <p>Requires EXECUTE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_create_job(job_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobCreateRequest job_create_request: the information needed to create the job. (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_create_job_with_http_info(job_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.job_create_job_with_http_info(job_create_request, **kwargs)  # noqa: E501
            return data

    def job_create_job_with_http_info(self, job_create_request, **kwargs):  # noqa: E501
        """createJob  # noqa: E501

        Creates and starts a new job asynchronously. <p>Requires EXECUTE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_create_job_with_http_info(job_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobCreateRequest job_create_request: the information needed to create the job. (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['job_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_create_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'job_create_request' is set
        if ('job_create_request' not in local_var_params or
                local_var_params['job_create_request'] is None):
            raise ValueError("Missing the required parameter `job_create_request` when calling `job_create_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_create_request' in local_var_params:
            body_params = local_var_params['job_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/jobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_delete_job(self, id, job_delete_request, **kwargs):  # noqa: E501
        """deleteJob  # noqa: E501

        Deletes a currently running job and preserves the job state in history. <p>Requires EXECUTE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_delete_job(id, job_delete_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The job id (required)
        :param JobDeleteRequest job_delete_request: The delete request (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_delete_job_with_http_info(id, job_delete_request, **kwargs)  # noqa: E501
        else:
            (data) = self.job_delete_job_with_http_info(id, job_delete_request, **kwargs)  # noqa: E501
            return data

    def job_delete_job_with_http_info(self, id, job_delete_request, **kwargs):  # noqa: E501
        """deleteJob  # noqa: E501

        Deletes a currently running job and preserves the job state in history. <p>Requires EXECUTE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_delete_job_with_http_info(id, job_delete_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The job id (required)
        :param JobDeleteRequest job_delete_request: The delete request (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id', 'job_delete_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_delete_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in local_var_params or
                local_var_params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `job_delete_job`")  # noqa: E501
        # verify the required parameter 'job_delete_request' is set
        if ('job_delete_request' not in local_var_params or
                local_var_params['job_delete_request'] is None):
            raise ValueError("Missing the required parameter `job_delete_request` when calling `job_delete_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_delete_request' in local_var_params:
            body_params = local_var_params['job_delete_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/jobs/ids/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_get_job(self, id, **kwargs):  # noqa: E501
        """getJob  # noqa: E501

        Gets the details of a previously submitted job. <p>Requires READ permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_get_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: the job id. (required)
        :param bool verbose:
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_get_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.job_get_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def job_get_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """getJob  # noqa: E501

        Gets the details of a previously submitted job. <p>Requires READ permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_get_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: the job id. (required)
        :param bool verbose:
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id', 'verbose']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_get_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in local_var_params or
                local_var_params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `job_get_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'verbose' in local_var_params:
            query_params.append(('verbose', local_var_params['verbose']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/jobs/ids/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_get_jobs(self, **kwargs):  # noqa: E501
        """getJobs  # noqa: E501

        <p>Gets a list of job executions based on the specified filter parameters.</p> <p>Jobs' namespace to which you do not have READ permissions to will be omitted from the result.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_get_jobs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: an optional namespace filter
        :param str job_name: an optional job name filter
        :param str status: an optional job status filter
        :param str start_time: an optional start time filter (ex. 2015, 2015-12, 2015-12-28, 2015-12-12T3:4:5)
        :param str end_time: an optional end time filter (ex. 2015, 2015-12, 2015-12-28, 2015-12-12T3:4:5)
        :return: JobSummaries
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_get_jobs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.job_get_jobs_with_http_info(**kwargs)  # noqa: E501
            return data

    def job_get_jobs_with_http_info(self, **kwargs):  # noqa: E501
        """getJobs  # noqa: E501

        <p>Gets a list of job executions based on the specified filter parameters.</p> <p>Jobs' namespace to which you do not have READ permissions to will be omitted from the result.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_get_jobs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: an optional namespace filter
        :param str job_name: an optional job name filter
        :param str status: an optional job status filter
        :param str start_time: an optional start time filter (ex. 2015, 2015-12, 2015-12-28, 2015-12-12T3:4:5)
        :param str end_time: an optional end time filter (ex. 2015, 2015-12, 2015-12-28, 2015-12-12T3:4:5)
        :return: JobSummaries
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'job_name', 'status', 'start_time', 'end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_get_jobs" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'namespace' in local_var_params:
            query_params.append(('namespace', local_var_params['namespace']))  # noqa: E501
        if 'job_name' in local_var_params:
            query_params.append(('jobName', local_var_params['job_name']))  # noqa: E501
        if 'status' in local_var_params:
            query_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'start_time' in local_var_params:
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params:
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobSummaries',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_signal_job(self, job_signal_request, **kwargs):  # noqa: E501
        """signalJob  # noqa: E501

        Signals the job with the receive task. <p>Requires EXECUTE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_signal_job(job_signal_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobSignalRequest job_signal_request: the information needed to signal the job. (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_signal_job_with_http_info(job_signal_request, **kwargs)  # noqa: E501
        else:
            (data) = self.job_signal_job_with_http_info(job_signal_request, **kwargs)  # noqa: E501
            return data

    def job_signal_job_with_http_info(self, job_signal_request, **kwargs):  # noqa: E501
        """signalJob  # noqa: E501

        Signals the job with the receive task. <p>Requires EXECUTE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_signal_job_with_http_info(job_signal_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobSignalRequest job_signal_request: the information needed to signal the job. (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['job_signal_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_signal_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'job_signal_request' is set
        if ('job_signal_request' not in local_var_params or
                local_var_params['job_signal_request'] is None):
            raise ValueError("Missing the required parameter `job_signal_request` when calling `job_signal_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_signal_request' in local_var_params:
            body_params = local_var_params['job_signal_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/jobs/signal', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_update_job(self, id, job_update_request, **kwargs):  # noqa: E501
        """updateJob  # noqa: E501

        Activates or suspends a job execution. <p>Requires EXECUTE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_update_job(id, job_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: the job id (required)
        :param JobUpdateRequest job_update_request: the job update request (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_update_job_with_http_info(id, job_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.job_update_job_with_http_info(id, job_update_request, **kwargs)  # noqa: E501
            return data

    def job_update_job_with_http_info(self, id, job_update_request, **kwargs):  # noqa: E501
        """updateJob  # noqa: E501

        Activates or suspends a job execution. <p>Requires EXECUTE permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_update_job_with_http_info(id, job_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: the job id (required)
        :param JobUpdateRequest job_update_request: the job update request (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id', 'job_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_update_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in local_var_params or
                local_var_params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `job_update_job`")  # noqa: E501
        # verify the required parameter 'job_update_request' is set
        if ('job_update_request' not in local_var_params or
                local_var_params['job_update_request'] is None):
            raise ValueError("Missing the required parameter `job_update_request` when calling `job_update_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_update_request' in local_var_params:
            body_params = local_var_params['job_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/jobs/ids/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
